YOLOModelManager class

Constructors

YOLOModelManager({required MethodChannel channel, required String instanceId, required String modelPath, required YOLOTask task, required bool useGpu, Map<String, dynamic>? classifierOptions, int? viewId, int? numItemsThreshold})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
initializeInstance() Future<void>
loadModel() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
predictorInstance() Future<void>
setViewId(int viewId) → void
switchModel(String newModelPath, YOLOTask newTask) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

downloadProgress Stream<DownloadProgress>
Stream of in-flight model-download progress events.
no setter

Static Methods

cancelDownload(String modelId) → void
clearDownloadCancellation(String modelId) → void
emitProgress(String modelId, double fraction) → void
Emits a DownloadProgress event. Called by the model resolver during streaming downloads; safe to call from any isolate that runs the resolver (Flutter UI isolate in practice).
finishDownload(String modelId, Object token) → void
isDownloadCancelled(String modelId, Object token) bool
registerDownload(String modelId, void cancel()) Object