YOLOSemanticMask class
Dense full-image semantic segmentation result.
Constructors
-
YOLOSemanticMask({required List<
int> classMap, required int width, required int height}) - YOLOSemanticMask.fromMap(Map map)
-
factory
Properties
-
classMap
→ List<
int> -
Row-major class index for each mask pixel.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
Mask height in pixels.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int
-
Mask width in pixels.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited