YOLOModelResolver class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
defaultOfficialModel(
{YOLOTask task = YOLOTask.detect}) → String? -
inspect(
String modelPath) → Future< Map< String, dynamic> > -
isOfficialModel(
String source) → bool -
isOfficialModelAvailableLocally(
String modelId) → Future< bool> -
Whether official
modelIdis already available without a network download. -
officialModelDownloadUrlForTesting(
String modelId, {required bool iosLike}) → String? -
officialModels(
{YOLOTask? task}) → List< String> -
preparePath(
String modelPath) → Future< String> -
resolve(
{required String modelPath, YOLOTask? task}) → Future< YOLOResolvedModel>